@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for codedeploy service client waiters.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_codedeploy import CodeDeployClient
-    from mypy_boto3_codedeploy import (
+    from mypy_boto3_codedeploy.waiter import (
         DeploymentSuccessfulWaiter,
     )
 
@@ -16,21 +17,19 @@ Usage::
     deployment_successful_waiter: DeploymentSuccessfulWaiter = client.get_waiter("deployment_successful")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_codedeploy.type_defs import WaiterConfigTypeDef
 
+from mypy_boto3_codedeploy.type_defs import WaiterConfigTypeDef
 
 __all__ = ("DeploymentSuccessfulWaiter",)
 
 
 class DeploymentSuccessfulWaiter(Boto3Waiter):
     """
-    [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
+    [Waiter.DeploymentSuccessful documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
     """
 
     def wait(self, deploymentId: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [DeploymentSuccessful.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful.wait)
+        [DeploymentSuccessful.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.7/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful.wait)
         """
